# Digital Operational Resilience Act (DORA) Attributes
### On this page
  * [Fields and Relations in Application and IT Component Fact Sheets](https://help.sap.com/docs/leanix/ea/digital-operational-resilience-act-dora-attributes#fields-and-relations-in-application-and-it-component-fact-sheets)
  * [Fields and Relations in Business Context Fact Sheets](https://help.sap.com/docs/leanix/ea/digital-operational-resilience-act-dora-attributes#fields-and-relations-in-business-context-fact-sheets)
  * [Fields and Relations in Provider Fact Sheet](https://help.sap.com/docs/leanix/ea/digital-operational-resilience-act-dora-attributes#fields-and-relations-in-provider-fact-sheet)


Learn which attributes are available with the Digital Operational Resilience Act (DORA) extension.
The meta model extension as part of the DORA extension includes a set of DORA-specific attributes. Most of the DORA-related attributes are organized within a dedicated section called DORA (Digital Operational Resilience Act). These attributes are further grouped into subcategories to provide better structure and clarity.
